@@ -2,16 +2,10 @@ import sympy as sy
 import IPython
 
 DatosList = []
-Orden = 0
+Orden = 8
 
 #Funciones para economizar tiempo
 
-def F(string):
-  return sy.Function(string)
-
-def s(string):
-  return sy.symbols(string)
-
 #Funciones de Redondeo
 def Redondear(expr):#Redondeamos la expresión.
   if isinstance(expr, sy.Expr) or isinstance(expr, sy.Float):
@@ -88,8 +82,6 @@ def G(c_componente):#Guardar
   else:
     D(c_componente,"red")#Hacemos un print renderizado en color gris para indicar que el elemento ha sido definido/guardado
 
-
-#Arreglar
 def A(c_componente):#Actualizar
   color = "red"
   for element in DatosList:
